# g-sheet-x

[![Python version](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%203.12%20%7C%203.13-blue.svg)](https://pypi.org/project/gsheetx/)
[![PyPI version](https://badge.fury.io/py/gsheetx.svg)](https://badge.fury.io/py/gsheetx)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/Minyus/g-sheet-x/blob/main/LICENSE)

CLI for Google Sheet

## Authentication

Follow: <https://docs.gspread.org/en/v6.1.3/oauth2.html>
